@@ -3,11 +3,12 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-	#if ( defined(__WIN64__) && !defined(__CYGWIN64__))
-		typedef struct stat64 STAT;
+	#if defined(__MINGW32__) || defined(__MINGW64__) 
+		typedef struct _stati64 STAT; // your bunny microsoft
 	#else
 		typedef struct stat STAT;
 	#endif
 
 
 #endif
+         
\ No newline at end of file
